@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2007 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
  *   http://www.xm1math.net/texmaker/                                      *
  *   addons by Luis Silvestre                                              *
  *                                                                         *
@@ -28,8 +28,11 @@
 #include <QModelIndex>
 #include <QAbstractItemModel>
 #include <QScrollBar>
+#include <QTextCodec>
+#include <QFile>
+#include "blockdata.h"
 
-LatexEditor::LatexEditor(QWidget *parent,QFont & efont, QColor colMath, QColor colCommand, QColor colKeyword) : QTextEdit(parent),c(0)
+LatexEditor::LatexEditor(QWidget *parent,QFont & efont, QColor colMath, QColor colCommand, QColor colKeyword,bool inlinespelling,QString ignoredWords,Hunspell *spellChecker) : QTextEdit(parent),c(0)
 {
 QPalette p = palette();
 p.setColor(QPalette::Inactive, QPalette::Highlight,p.color(QPalette::Active, QPalette::Highlight));
@@ -43,8 +46,29 @@ encoding="";
 setFont(efont);
 setTabStopWidth(fontMetrics().width("    "));
 setTabChangesFocus(false);
-highlighter = new LatexHighlighter(document());
+
+/*********************************/
+inlinecheckSpelling=inlinespelling;
+pChecker = spellChecker;
+if (pChecker) spell_encoding=QString(pChecker->get_dic_encoding());
+if (!ignoredWords.isEmpty()) alwaysignoredwordList=ignoredWords.split(",");
+else alwaysignoredwordList.clear();
+ignoredwordList=alwaysignoredwordList;
+QFile wordsfile(":/spell/spellignore.txt");
+QString line;
+if (wordsfile.open(QFile::ReadOnly))
+    {
+    while (!wordsfile.atEnd()) 
+	    {
+	    line = wordsfile.readLine();
+	    if (!line.isEmpty()) hardignoredwordList.append(line.trimmed());
+	    }
+    }
+/********************************/
+
+highlighter = new LatexHighlighter(document(),inlinespelling,ignoredWords,spellChecker);
 highlighter->setColors(colMath,colCommand,colKeyword);
+
 //c=0;
 connect(this, SIGNAL(cursorPositionChanged()), viewport(), SLOT(update()));
  matcher = new ParenMatcher;
@@ -54,6 +78,7 @@ setFocus();
 }
 LatexEditor::~LatexEditor(){
 delete matcher;
+//delete pChecker;
 }
 
  void LatexEditor::clearMarkerFormat(const QTextBlock &block, int markerId)
@@ -92,6 +117,83 @@ void LatexEditor::contextMenuEvent(QContextMenuEvent *e)
 {
 QMenu *menu=new QMenu(this);
 QAction *a;
+/*******************************************/
+if (inlinecheckSpelling && pChecker)
+      {
+      QFont spellmenufont (qApp->font());
+      spellmenufont.setBold(true);
+      QTextCursor c = cursorForPosition(e->pos());
+      BlockData* data;
+      QTextCodec *codec = QTextCodec::codecForName(spell_encoding.toLatin1());
+      QByteArray encodedString;
+      QTextBlock block;
+      QString text,word;
+      bool gonext=true;
+      QByteArray t;
+      int li,cols,cole,colstart,colend,check,ns;
+      char ** wlst;
+      QStringList suggWords;
+      //c.movePosition(QTextCursor::NextCharacter,QTextCursor::MoveAnchor);
+      c.movePosition(QTextCursor::StartOfWord,QTextCursor::MoveAnchor);
+      data = (BlockData*)c.block().userData();
+      li=c.blockNumber();
+      block=c.block();
+      colstart=c.position()-block.position();
+      c.movePosition(QTextCursor::EndOfWord,QTextCursor::KeepAnchor);
+      block=c.block();
+      colend=c.position()-block.position()-1;
+      cols=colstart;
+      text=c.selectedText();
+      while ((cols<colend && cols<data->code.count() && data->code[cols]==1) || text.mid(cols-colstart,1)==" " || text.mid(cols-colstart,1)=="\t" )
+	      {
+	      cols++;
+	      }
+      cole=colend;
+      while (cole>colstart && cole<data->code.count() && data->code[cole]==1)
+	      {
+	      cole--;
+	      }
+      if (text.length()>1 && cole>cols)
+	      {
+	      word=text.mid(cols-colstart,cole-cols+1);
+	      if (!ignoredwordList.contains(word) && !hardignoredwordList.contains(word))
+		      {
+		      encodedString = codec->fromUnicode(word);
+		      check = pChecker->spell(encodedString.data());
+		      if (!check)
+			      {
+			      selectword(li,cols,word);
+			      gonext=false;
+			      ns = pChecker->suggest(&wlst,encodedString.data());
+			      if (ns > 0)
+				      {
+				      suggWords.clear();
+				      for (int i=0; i < ns; i++) 
+					      {
+					      suggWords.append(codec->toUnicode(wlst[i]));
+				      //free(wlst[i]);
+					      } 
+			      //free(wlst);
+				      pChecker->free_list(&wlst, ns);
+				      if (!suggWords.isEmpty())
+					      {
+					      if (suggWords.contains(word)) gonext=true;
+					      else
+						      {
+						      foreach (const QString &suggestion, suggWords)
+							  {
+							  a = menu->addAction(suggestion, this, SLOT(correctWord()));
+							  a->setFont(spellmenufont);
+							  }
+						      }
+					      }
+				      }
+			      }
+		      }
+	      }
+      menu->addSeparator();
+      }
+/*******************************************/
 a = menu->addAction(tr("Undo"), this, SLOT(undo()));
 a->setShortcut(Qt::CTRL+Qt::Key_Z);
 a->setEnabled(document()->isUndoAvailable());
@@ -124,6 +226,16 @@ menu->exec(e->globalPos());
 delete menu;
 }
 
+void LatexEditor::correctWord()
+{
+QAction *action = qobject_cast<QAction *>(sender());
+if (action)
+	{
+	QString newword = action->text();
+	replace(newword);
+	}
+}
+
 bool LatexEditor::search( const QString &expr, bool cs, bool wo, bool forward, bool startAtCursor )
 {
 QTextDocument::FindFlags flags = 0;
@@ -224,7 +336,7 @@ if (cur.hasSelection())
 	cur.movePosition(QTextCursor::StartOfBlock,QTextCursor::MoveAnchor);
 	while ( cur.position() < end && go)
 		{
-		cur.movePosition(QTextCursor::Right,QTextCursor::KeepAnchor);
+		cur.movePosition(QTextCursor::NextCharacter,QTextCursor::KeepAnchor);
 		if (cur.selectedText()=="%") 
 			{
 			cur.removeSelectedText();
@@ -275,15 +387,7 @@ void LatexEditor::setEncoding(QString enc)
 
 int LatexEditor::getCursorPosition(int para, int index)
 {
-int i = 0;
-QTextBlock p = document()->begin();
-while ( p.isValid() ) 
-	{
-	if (para==i) break;
-	i++;
-	p = p.next();
-	}
-return p.position()+index;
+return document()->findBlockByNumber(para).position()+index;
 }
 
 void LatexEditor::setCursorPosition(int para, int index)
@@ -323,24 +427,12 @@ setFocus();
 
 int LatexEditor::numoflines()
 {
-int num=0;
-QTextBlock p;
-for (p = document()->begin(); p.isValid(); p = p.next()) ++num;
-return num;
+return document()->blockCount();
 }
 
 int LatexEditor::linefromblock(const QTextBlock& p)
 {
-if (!p.isValid()) return -1;
-int num = 1;
-QTextBlock block=document()->begin();
-while (block.isValid())
-	{
-	if ( p == block ) return num;
-	num++;
-	block = block.next();
-	}
-return -1;
+return p.blockNumber()+1;
 }
 
 void LatexEditor::selectword(int line, int col, QString word)
@@ -480,6 +572,8 @@ static QString eow("~!@#$%^&*()_+{}|:\"<>?,./;'[]-= "); // end of word
 bool hasModifier = (e->modifiers() & ( Qt::ControlModifier | Qt::AltModifier ));
 //bool hasModifier = (e->modifiers() != Qt::NoModifier) && !ctrlOrShift;
 QString completionPrefix = textUnderCursor();
+
+
 if (hasModifier || e->text().isEmpty()|| completionPrefix.length() < 3 || eow.contains(e->text().right(1)))
 //if (!isShortcut && (hasModifier || e->text().isEmpty()|| completionPrefix.length() < 3 || eow.contains(e->text().right(1)))) 
 	{
@@ -516,7 +610,11 @@ QObject::connect(c, SIGNAL(activated(const QString&)),this, SLOT(insertCompletio
 {
 if (c->widget() != this) return;
 QTextCursor tc = textCursor();
-int extra = completion.length() - c->completionPrefix().length();
+int extra = completion.length();// - c->completionPrefix().length();
+//tc.movePosition(QTextCursor::PreviousCharacter,QTextCursor::KeepAnchor, c->completionPrefix().length());
+tc.movePosition(QTextCursor::PreviousCharacter,QTextCursor::KeepAnchor, textUnderCursor().size());//Add by S. R. Alavizadeh
+tc.removeSelectedText();
+//int extra = completion.length() - c->completionPrefix().length();
 //tc.movePosition(QTextCursor::Left);
 //tc.movePosition(QTextCursor::EndOfWord);
 int pos=tc.position();
@@ -570,3 +668,16 @@ setTextCursor(tc);
 if (c) c->setWidget(this);
 QTextEdit::focusInEvent(e);
 }
+
+ void LatexEditor::setSpellChecker(Hunspell * checker)
+{
+pChecker = checker;
+if (pChecker) spell_encoding=QString(pChecker->get_dic_encoding());
+}
+
+void LatexEditor::activateInlineSpell(bool enable)
+{
+inlinecheckSpelling=enable;
+}
+
+
