@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2007 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
  *   http://www.xm1math.net/texmaker/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -17,11 +17,13 @@
 #include <QMenuBar>
 #include <QToolBar>
 #include <QListWidget>
-#include <QToolBox>
+#include <QStackedWidget>
 #include <QTabWidget>
 #include <QTreeWidget>
+#include <QListWidget>
 #include <QLabel>
 #include <QAction>
+#include <QActionGroup>
 #include <QTreeWidgetItem>
 #include <QListWidgetItem>
 #include <QTableWidgetItem>
@@ -33,14 +35,15 @@
 #include <QTextTable>
 #include <QVBoxLayout>
 #include <QTableWidget>
+#include <QTranslator>
 
 #include "latexeditorview.h"
 #include "symbollistwidget.h"
-#include "metapostlistwidget.h"
-#include "pstrickslistwidget.h"
+#include "xmltagslistwidget.h"
 #include "logeditor.h"
 #include "gotolinedialog.h"
 #include "replacedialog.h"
+#include "hunspell/hunspell.hxx"
 
 
 
@@ -56,10 +59,11 @@ class Texmaker : public QMainWindow
 
 public:
     Texmaker(QWidget *parent = 0, Qt::WFlags flags = 0);
-
+    ~Texmaker();
 QString getName();
 QFont EditorFont;
 QByteArray windowstate;
+
 public slots:
 void load( const QString &f );
 void setLine( const QString &line );
@@ -79,12 +83,14 @@ KeysMap shortcuts, actionstext;
 QDockWidget *OutputView, *StructureView;
 QTabWidget *EditorView;
 LogEditor* OutputTextEdit;
-QToolBox *StructureToolbox;
-MetapostListWidget *MpListWidget;
-PstricksListWidget *PsListWidget;
-SymbolListWidget *RelationListWidget, *ArrowListWidget, *MiscellaneousListWidget, *DelimitersListWidget, *GreekListWidget, *MostUsedListWidget;
+
+//QToolBox *StructureToolbox;
+QStackedWidget *LeftPanelStackedWidget;
+XmlTagsListWidget *MpListWidget, *PsListWidget, *leftrightWidget, *tikzWidget, *asyWidget;
+SymbolListWidget *RelationListWidget, *ArrowListWidget, *MiscellaneousListWidget, *DelimitersListWidget, *GreekListWidget, *MostUsedListWidget, *FavoriteListWidget;
 QTreeWidget *StructureTreeWidget;
-QVBoxLayout *OutputLayout;
+QVBoxLayout *OutputLayoutV;
+QHBoxLayout *OutputLayoutH, *LeftPanelLayout, *CentralLayout;
 QTableWidget *OutputTableWidget;
 //menu-toolbar
 QMenu *fileMenu, *recentMenu, *editMenu, *toolMenu;
@@ -94,23 +100,24 @@ QMenu *wizardMenu;
 QMenu *bibMenu;
 QMenu *user1Menu, *user11Menu, *user12Menu;
 QMenu *viewMenu;
-QMenu *optionsMenu;
+QMenu *optionsMenu, *translationMenu, *appearanceMenu;
 QMenu *helpMenu;
 
-QToolBar *fileToolBar, *editToolBar, *runToolBar, *formatToolBar, *mathToolBar;
+QToolBar *fileToolBar, *editToolBar, *runToolBar, *formatToolBar, *logToolBar, *LeftPanelToolBar, *centralToolBar;
 QAction *recentFileActs[5], *ToggleAct;
+QComboBox *comboCompil, *comboView;
 
 QLabel *stat1, *stat2, *stat3;
 QPushButton *pb1, *pb2, *pb3;
 QString MasterName;
 bool logpresent;
-QStringList recentFilesList;
+QStringList recentFilesList, sessionFilesList;
 //settings
 int split1_right, split1_left, split2_top, split2_bottom, quickmode;
-bool singlemode, wordwrap, parenmatch, showline, showoutputview, showstructview, ams_packages, makeidx_package, completion;
+bool singlemode, wordwrap, parenmatch, showline, showoutputview, showstructview, ams_packages, makeidx_package, completion, inlinespellcheck, modern_style, new_gui;
 QString document_class, typeface_size, paper_size, document_encoding, author;
 QString latex_command, viewdvi_command, dvips_command, dvipdf_command, metapost_command;
-QString viewps_command, ps2pdf_command, makeindex_command, bibtex_command, pdflatex_command, viewpdf_command, userquick_command, ghostscript_command;
+QString viewps_command, ps2pdf_command, makeindex_command, bibtex_command, pdflatex_command, viewpdf_command, userquick_command, ghostscript_command, asymptote_command;
 QString spell_dic, spell_ignored_words;
 QString lastDocument, input_encoding;
 QString struct_level1, struct_level2, struct_level3, struct_level4, struct_level5;
@@ -128,7 +135,7 @@ bool FINPROCESS, ERRPROCESS;
 //latex errors
 QStringList errorFileList, errorTypeList, errorLineList, errorMessageList, errorLogList;
 QList<int> onlyErrorList;
-int errorIndex;
+int errorIndex, runIndex, viewIndex;
 
 //X11
 #if defined( Q_WS_X11 )
@@ -138,10 +145,15 @@ int x11fontsize;
 #endif
 SymbolList symbolScore;
 usercodelist symbolMostused;
+QList<int> favoriteSymbolList;
 
 QColor colorMath, colorCommand, colorKeyword;
 
 QCompleter *completer;
+Hunspell * spellChecker;
+bool spelldicExist();
+QStringList translationList;
+QActionGroup *translationGroup, *appearanceGroup;
 
 private slots:
 LatexEditorView *currentEditorView() const;
@@ -150,7 +162,9 @@ void fileOpen();
 void fileSave();
 void fileSaveAll();
 void fileSaveAs();
+void fileRestoreSession();
 void fileClose();
+void fileCloseRequested( int index);
 void fileCloseAll();
 void fileExit();
 void fileOpenRecent();
@@ -182,12 +196,23 @@ void UpdateCaption();
 
 void UpdateStructure();
 void ShowStructure();
+void ShowRelation(); //RelationListWidget
+void ShowArrow(); //ArrowListWidget
+void ShowMisc(); //MiscellaneousListWidget
+void ShowDelim(); //DelimitersListWidget
+void ShowGreek(); //GreekListWidget
+void ShowMostUsed(); //MostUsedListWidget
+void ShowFavorite(); //FavoriteListWidget
+void ShowPstricks(); //PsListWidget
+void ShowLeftRight(); //leftrightWidget
+void ShowMplist(); //MpListWidget
+void ShowTikz(); //tikzWidget
+void ShowAsy(); //asyWidget
 void ClickedOnStructure(QTreeWidgetItem *item,int);
 
 void InsertTag(QString Entity, int dx, int dy);
 void InsertSymbol(QTableWidgetItem *item);
-void InsertMetaPost(QListWidgetItem *item);
-void InsertPstricks(QListWidgetItem *item);
+void InsertXmlTag(QListWidgetItem *item);
 void InsertFromAction();
 void InsertWithSelectionFromAction();
 void InsertWithSelectionFromString(const QString& text);
@@ -231,8 +256,6 @@ void OtherCommand(const QString& text);
 void InsertRef();
 void InsertPageRef();
 void SizeCommand(const QString& text);
-void LeftDelimiter(const QString& text);
-void RightDelimiter(const QString& text);
 
 void QuickTabular();
 void QuickArray();
@@ -257,12 +280,15 @@ void MakeIndex();
 void PStoPDF();
 void DVItoPDF();
 void MetaPost();
+void Asymptote();
 void UserTool1();
 void UserTool2();
 void UserTool3();
 void UserTool4();
 void UserTool5();
 void EditUserTool();
+void doCompile();
+void doView();
 
 void WebPublish();
 
@@ -285,7 +311,6 @@ void GeneralOptions();
 
 void gotoNextDocument();
 void gotoPrevDocument();
-//void ToggleMode();
 
 void SetInterfaceFont();
 
@@ -294,10 +319,16 @@ void gotoBookmark2();
 void gotoBookmark3();
 
 void SetMostUsedSymbols();
+void InsertFavoriteSymbols();
+void RemoveFavoriteSymbols();
+
 
 void ModifyShortcuts();
 
 void updateCompleter();
+void updateTranslation();
+void updateAppearance();
+
 
 protected:
 void dragEnterEvent(QDragEnterEvent *event);
